aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTim Harder <radhermit@gmail.com>2018-01-11 22:42:23 -0500
committerTim Harder <radhermit@gmail.com>2018-03-06 23:52:25 -0500
commit41597b64ef21e15f687a748ff7b14e8f11b331c8 (patch)
tree99d058ca25fd8937d80726c2bb7157527951815d
parentebd/ebuild-default-functions.lib: minor typo fix (diff)
downloadpkgcore-41597b64ef21e15f687a748ff7b14e8f11b331c8.tar.gz
pkgcore-41597b64ef21e15f687a748ff7b14e8f11b331c8.tar.bz2
pkgcore-41597b64ef21e15f687a748ff7b14e8f11b331c8.zip
use 'repos' instead of 'repositories'
-rw-r--r--src/pkgcore/config/dhcpformat.py2
-rw-r--r--src/pkgcore/config/mke2fsformat.py2
-rw-r--r--src/pkgcore/ebuild/domain.py14
-rw-r--r--src/pkgcore/ebuild/portage_conf.py4
-rw-r--r--src/pkgcore/operations/domain.py2
-rw-r--r--src/pkgcore/repository/multiplex.py10
-rw-r--r--src/pkgcore/repository/util.py2
-rw-r--r--src/pkgcore/resolver/plan.py2
-rw-r--r--src/pkgcore/scripts/pinspect.py38
-rw-r--r--src/pkgcore/scripts/pmaint.py6
-rw-r--r--src/pkgcore/scripts/pquery.py10
11 files changed, 46 insertions, 46 deletions
diff --git a/src/pkgcore/config/dhcpformat.py b/src/pkgcore/config/dhcpformat.py
index 834bce0e9..e02f21f5e 100644
--- a/src/pkgcore/config/dhcpformat.py
+++ b/src/pkgcore/config/dhcpformat.py
@@ -23,7 +23,7 @@ Example of the supported format (not a complete config)::
package.keywords "/etc/portage/package.keywords";
default yes;
# this is a section reference, with a nested anonymous section.
- repositories {
+ repos {
type repo;
class pkgcore.ebuild.repository.tree;
location /var/gentoo/repos/gentoo;
diff --git a/src/pkgcore/config/mke2fsformat.py b/src/pkgcore/config/mke2fsformat.py
index 832bc1721..33913edf7 100644
--- a/src/pkgcore/config/mke2fsformat.py
+++ b/src/pkgcore/config/mke2fsformat.py
@@ -23,7 +23,7 @@ Example of the supported format (not a complete config)::
package.keywords = "/etc/portage/package.keywords"
default = yes
# this is a section reference, with a nested anonymous section.
- repositories = {
+ repos = {
type = repo
class = pkgcore.ebuild.repository.tree
location = /var/gentoo/repos/gentoo
diff --git a/src/pkgcore/ebuild/domain.py b/src/pkgcore/ebuild/domain.py
index 5518f8948..78cec35fc 100644
--- a/src/pkgcore/ebuild/domain.py
+++ b/src/pkgcore/ebuild/domain.py
@@ -173,7 +173,7 @@ class domain(config_domain):
# XXX ouch, verify this crap and add defaults and stuff
_types = {
'profile': 'ref:profile', 'fetcher': 'ref:fetcher',
- 'repositories': 'lazy_refs:repo', 'vdb': 'lazy_refs:repo',
+ 'repos': 'lazy_refs:repo', 'vdb': 'lazy_refs:repo',
'name': 'str', 'triggers': 'lazy_refs:trigger',
}
for _thing in ('root', 'config_dir', 'CHOST', 'CBUILD', 'CTARGET', 'CFLAGS', 'PATH',
@@ -186,12 +186,12 @@ class domain(config_domain):
# TODO this is missing defaults
pkgcore_config_type = ConfigHint(
_types, typename='domain',
- required=['repositories', 'profile', 'vdb', 'fetcher', 'name'],
+ required=['repos', 'profile', 'vdb', 'fetcher', 'name'],
allow_unknowns=True)
del _types, _thing
- def __init__(self, profile, repositories, vdb, name=None,
+ def __init__(self, profile, repos, vdb, name=None,
root='/', config_dir='/etc/portage', prefix='/',
triggers=(), **settings):
self._triggers = triggers
@@ -202,8 +202,8 @@ class domain(config_domain):
self.ebuild_hook_dir = pjoin(self.config_dir, 'env')
self.profile = profile
self.fetcher = settings.pop("fetcher")
- self._repositories = repositories
- self._vdb = vdb
+ self.__repos = repos
+ self.__vdb = vdb
# prevent critical variables from being changed in make.conf
for k in self.profile.profile_only_variables.intersection(settings.keys()):
@@ -689,12 +689,12 @@ class domain(config_domain):
@klass.jit_attr_none
def source_repos_raw(self):
"""Group of package repos without filtering."""
- return RepositoryGroup(r.instantiate() for r in self._repositories)
+ return RepositoryGroup(r.instantiate() for r in self.__repos)
@klass.jit_attr_none
def installed_repos_raw(self):
"""Group of installed repos without filtering."""
- repos = [r.instantiate() for r in self._vdb]
+ repos = [r.instantiate() for r in self.__vdb]
if self.profile.provides_repo is not None:
repos.append(self.profile.provides_repo)
return RepositoryGroup(repos)
diff --git a/src/pkgcore/ebuild/portage_conf.py b/src/pkgcore/ebuild/portage_conf.py
index a78aaf9cc..a9a02e448 100644
--- a/src/pkgcore/ebuild/portage_conf.py
+++ b/src/pkgcore/ebuild/portage_conf.py
@@ -509,7 +509,7 @@ def config_from_make_conf(location=None, profile_override=None, **kwargs):
config['repo-stack'] = basics.FakeIncrementalDictConfigSection(
my_convert_hybrid, {
'class': 'pkgcore.repository.multiplex.config_tree',
- 'repositories': tuple(repos)})
+ 'repos': tuple(repos)})
else:
config['repo-stack'] = basics.section_alias(repos[0], 'repo')
@@ -571,7 +571,7 @@ def config_from_make_conf(location=None, profile_override=None, **kwargs):
# finally... domain.
make_conf.update({
'class': 'pkgcore.ebuild.domain.domain',
- 'repositories': tuple(repos),
+ 'repos': tuple(repos),
'fetcher': 'fetcher',
'default': True,
'vdb': ('vdb',),
diff --git a/src/pkgcore/operations/domain.py b/src/pkgcore/operations/domain.py
index 4135e62c8..ecf96eefd 100644
--- a/src/pkgcore/operations/domain.py
+++ b/src/pkgcore/operations/domain.py
@@ -129,7 +129,7 @@ class base(object):
class install(base):
"""base interface for installing a pkg into a livefs repo.
- repositories should override as needed.
+ Repositories should override as needed.
"""
stage_depends = {
diff --git a/src/pkgcore/repository/util.py b/src/pkgcore/repository/util.py
index e2a441cee..dc53b8784 100644
--- a/src/pkgcore/repository/util.py
+++ b/src/pkgcore/repository/util.py
@@ -70,7 +70,7 @@ class SimpleTree(prototype.tree):
class RepositoryGroup(DictMixin):
- """Group of repositories as a single unit.
+ """Group of repos as a single unit.
Args:
repos (iterable): repo instances
diff --git a/src/pkgcore/resolver/plan.py b/src/pkgcore/resolver/plan.py
index 1199f0464..1c318cd27 100644
--- a/src/pkgcore/resolver/plan.py
+++ b/src/pkgcore/resolver/plan.py
@@ -831,7 +831,7 @@ class merge_plan(object):
:param dbs: db list to walk
:param just_vdb: if None, no filtering; if True, just vdb, if False,
non-vdb only
- :return: yields repositories in requested ordering
+ :return: yields repos in requested ordering
"""
return chain(cls.just_livefs_dbs(dbs), cls.just_nonlivefs_dbs(dbs))
diff --git a/src/pkgcore/scripts/pinspect.py b/src/pkgcore/scripts/pinspect.py
index 3540450d8..e4413ddc7 100644
--- a/src/pkgcore/scripts/pinspect.py
+++ b/src/pkgcore/scripts/pinspect.py
@@ -3,9 +3,9 @@
"""repository inspection interface
-pinspect is used to extract various information from repositories. For example,
+pinspect is used to extract various information from repos. For example,
it can perform aggregated EAPI, license, eclass, and mirror usage queries
-across specified repositories. Any repository type can be queried, e.g. ebuild,
+across specified repos. Any repo type can be queried, e.g. ebuild,
binary, or vdb.
It also provides an interface to all profile specific metadata, e.g. package
@@ -201,9 +201,9 @@ class histo_data(arghparse.ArgparseCommand):
class eapi_usage_kls(histo_data):
- per_repo_format = ("eapi: %(key)r %(val)s pkgs found, %(percent)s of the repository")
+ per_repo_format = ("eapi: %(key)r %(val)s pkgs found, %(percent)s of the repo")
- summary_format = ("eapi: %(key)r %(val)s pkgs found, %(percent)s of all repositories")
+ summary_format = ("eapi: %(key)r %(val)s pkgs found, %(percent)s of all repos")
def get_data(self, repo, options):
eapis = {}
@@ -214,15 +214,15 @@ class eapi_usage_kls(histo_data):
return eapis, pos + 1
eapi_usage = subparsers.add_parser(
- "eapi_usage", description="report of eapi usage for targeted repositories")
+ "eapi_usage", description="report of eapi usage for targeted repos")
eapi_usage.bind_class(eapi_usage_kls())
class license_usage_kls(histo_data):
- per_repo_format = "license: %(key)r %(val)s pkgs found, %(percent)s of the repository"
+ per_repo_format = "license: %(key)r %(val)s pkgs found, %(percent)s of the repo"
- summary_format = "license: %(key)r %(val)s pkgs found, %(percent)s of all repositories"
+ summary_format = "license: %(key)r %(val)s pkgs found, %(percent)s of all repos"
def get_data(self, repo, options):
data = {}
@@ -234,15 +234,15 @@ class license_usage_kls(histo_data):
return data, pos + 1
license_usage = subparsers.add_parser(
- "license_usage", description="report of license usage for targeted repositories")
+ "license_usage", description="report of license usage for targeted repos")
license_usage.bind_class(license_usage_kls())
class eclass_usage_kls(histo_data):
- per_repo_format = "eclass: %(key)r %(val)s pkgs found, %(percent)s of the repository"
+ per_repo_format = "eclass: %(key)r %(val)s pkgs found, %(percent)s of the repo"
- summary_format = "eclass: %(key)r %(val)s pkgs found, %(percent)s of all repositories"
+ summary_format = "eclass: %(key)r %(val)s pkgs found, %(percent)s of all repos"
def get_data(self, repo, options):
pos, data = 0, defaultdict(lambda:0)
@@ -252,15 +252,15 @@ class eclass_usage_kls(histo_data):
return data, pos + 1
eclass_usage = subparsers.add_parser(
- "eclass_usage", description="report of eclass usage for targeted repositories")
+ "eclass_usage", description="report of eclass usage for targeted repos")
eclass_usage.bind_class(eclass_usage_kls())
class mirror_usage_kls(histo_data):
- per_repo_format = "mirror: %(key)r %(val)s pkgs found, %(percent)s of the repository"
+ per_repo_format = "mirror: %(key)r %(val)s pkgs found, %(percent)s of the repo"
- summary_format = "mirror: %(key)r %(val)s pkgs found, %(percent)s of all repositories"
+ summary_format = "mirror: %(key)r %(val)s pkgs found, %(percent)s of all repos"
def get_data(self, repo, options):
data = {}
@@ -275,7 +275,7 @@ class mirror_usage_kls(histo_data):
return data, pos + 1
mirror_usage = subparsers.add_parser(
- "mirror_usage", description="report of SRC_URI mirror usage for targeted repositories")
+ "mirror_usage", description="report of SRC_URI mirror usage for targeted repos")
mirror_usage.bind_class(mirror_usage_kls())
@@ -285,7 +285,7 @@ class distfiles_usage_kls(histo_data):
per_repo_summary = "unique total %(total)i bytes, sharing %(shared)i bytes"
- summary_format = "package: %(key)r %(val)s pkgs found, %(percent)s of all repositories"
+ summary_format = "package: %(key)r %(val)s pkgs found, %(percent)s of all repos"
allow_no_detail = True
@@ -329,12 +329,12 @@ class distfiles_usage_kls(histo_data):
distfiles_usage = subparsers.add_parser(
"distfiles_usage",
- description="report detailing distfiles space usage for targeted repositories")
+ description="report detailing distfiles space usage for targeted repos")
distfiles_usage.bind_class(distfiles_usage_kls())
query = subparsers.add_parser(
"query",
- description="auxiliary access to ebuild/repository info via portageq akin api")
+ description="auxiliary access to ebuild/repo info via portageq akin api")
_portageq.bind_parser(query, name='query')
portageq = subparsers.add_parser(
@@ -353,7 +353,7 @@ inspect_profile.bind_parser(profile, 'profile')
digests = subparsers.add_parser(
"digests", domain=True, description="identify what packages are missing digest info")
digests.add_argument(
- 'repos', nargs='*', help="repository to inspect",
+ 'repos', nargs='*', help="repo to inspect",
action=commandline.StoreRepoObject, allow_external_repos=True, store_name=True)
@digests.bind_main_func
def digest_manifest(options, out, err):
@@ -381,6 +381,6 @@ def digest_manifest(options, out, err):
out.write("%i out of %i the tree has broken checksum data "
"(%2.2f%%)" % (broken, count, percent))
else:
- out.write("repository has no packages")
+ out.write("repo has no packages")
out.write()
diff --git a/src/pkgcore/repository/multiplex.py b/src/pkgcore/repository/multiplex.py
index 0077a6ca8..b6523d600 100644
--- a/src/pkgcore/repository/multiplex.py
+++ b/src/pkgcore/repository/multiplex.py
@@ -2,7 +2,7 @@
# License: GPL2/BSD
"""
-repository that combines multiple repositories together
+repository that combines multiple repos together
"""
__all__ = ("tree", "operations")
@@ -63,13 +63,13 @@ class operations(repo_interface.operations_proxy):
return ret
-@configurable({'repositories': 'refs:repo'}, typename='repo')
-def config_tree(repositories):
- return tree(*repositories)
+@configurable({'repos': 'refs:repo'}, typename='repo')
+def config_tree(repos):
+ return tree(*repos)
class tree(prototype.tree):
"""Repository combining multiple repositories together.
Args:
trees (list): :obj:`pkgcore.repository.prototype.tree` instances
@@ -63,13 +63,13 @@ class operations(repo_interface.operations_proxy):
class tree(prototype.tree):
- """Repository combining multiple repositories together.
+ """Repository combining multiple repos together.
Args:
trees (list): :obj:`pkgcore.repository.prototype.tree` instances
diff --git a/src/pkgcore/scripts/pmaint.py b/src/pkgcore/scripts/pmaint.py
index 4e68f293c..1df44e2f4 100644
--- a/src/pkgcore/scripts/pmaint.py
+++ b/src/pkgcore/scripts/pmaint.py
@@ -60,7 +60,7 @@ sync.add_argument(
action=commandline.StoreRepoObject, store_name=True, repo_type='config')
@sync.bind_main_func
def sync_main(options, out, err):
"""Update local repositories to match their remotes"""
verbosity = -1 if options.quiet else options.verbose
succeeded, failed = [], []
@@ -98,7 +98,7 @@ def sync_main(options, out, err):
# TODO: restrict to required repo types
copy = subparsers.add_parser(
"copy", parents=shared_options_domain,
- description="copy binpkgs between repositories; primarily useful for "
+ description="copy binpkgs between repos; primarily useful for "
"quickpkging a livefs pkg")
copy.add_argument(
'target_repo', action=commandline.StoreRepoObject, repo_type='binary-raw',
@@ -118,7 +118,7 @@ copy_opts.add_argument(
help="if a matching pkg already exists in the target, don't update it")
@copy.bind_main_func
def copy_main(options, out, err):
"""Copy pkgs between repositories."""
source_repo = options.source_repo
if source_repo is None:
source_repo = options.domain.all_source_repos
@@ -60,7 +60,7 @@ sync.add_argument(
def sync_main(options, out, err):
- """Update local repositories to match their remotes"""
+ """Update local repos to match their remotes."""
verbosity = -1 if options.quiet else options.verbose
succeeded, failed = [], []
@@ -118,7 +118,7 @@ copy_opts.add_argument(
def copy_main(options, out, err):
- """Copy pkgs between repositories."""
+ """Copy pkgs between repos."""
source_repo = options.source_repo
if source_repo is None:
diff --git a/src/pkgcore/scripts/pquery.py b/src/pkgcore/scripts/pquery.py
index 1197113fe..4fd4900f2 100644
--- a/src/pkgcore/scripts/pquery.py
+++ b/src/pkgcore/scripts/pquery.py
@@ -8,12 +8,12 @@ pquery is used to extract various kinds of information about either installed
or uninstalled packages. From an overall usage standpoint it is similar to
equery, but it can do things equery cannot do and is a bit more flexible.
-What pquery does is select packages from one or more "repositories" that match
+What pquery does is select packages from one or more repos that match
a boolean combination of restrictions, then print selected information about
those packages. It is important to understand that the information printing and
-repository selection options are almost completely separate from the
+repo selection options are almost completely separate from the
restriction options. The only exception to that is that restrictions on
-contents automatically select the vdb (installed packages) repository, since
+contents automatically select the vdb (installed packages) repo, since
running them on source repos makes no sense.
"""
@@ -451,7 +451,7 @@ def print_packages_noversion(options, out, err, pkgs):
# priority 0 (commandline sets this):
# basically, sort the config first (additions/removals/etc),
# priority 30:
# sort the repositories
# priority 50:
# sort the query args individually (potentially accessing the config) along
# or lines for each (thus multiple revdep args are or'd together)
@@ -466,7 +466,7 @@ argparser = commandline.ArgumentParser(
repo_group = argparser.add_argument_group(
'repository matching options',
- description='options controlling which repositories to inspect')
+ description='options controlling which repos to inspect')
repo_group.add_argument(
'--raw', action='store_true', default=False,
help="disable configuration filtering",
@@ -451,7 +451,7 @@ def print_packages_noversion(options, out, err, pkgs):
# basically, sort the config first (additions/removals/etc),
# priority 30:
-# sort the repositories
+# sort the repos
# priority 50:
# sort the query args individually (potentially accessing the config) along